/**
 * Some misc helpers to fetch env variables, infer string types, check json, etc.
 * @type {{infer(string): (boolean|null|*|number|undefined), is_json(*=): boolean, env(string, *=): (string|null|boolean|number)}}
 * @module libflitter/utility/Helpers
 */

module.exports = exports = {
    /**
     * Grabs an environment variable by name and tries to infer its type.
     * @param {string} name
     * @param default_value
     * @deprecated Prefer using {@link module:libflitter/utility/UtilityUnit~UtilityUnit}
     * @return {string|null|boolean|number}
     */
    env(name, default_value){
        const val = process.env[name]
        if ( !val ) return typeof default_value !== "undefined" ? default_value : null
        else return this.infer(val)
    },

    /**
     * Attempt to infer the variable type of a string's data.
     * @param {string} val
     * @deprecated Prefer using {@link module:libflitter/utility/UtilityUnit~UtilityUnit}
     * @return {boolean|null|*|number|undefined}
     */
    infer(val){
        if ( !val ) return null
        else if ( val.toLowerCase() === 'true' ) return true
        else if ( val.toLowerCase() === 'false' ) return false
        else if ( !isNaN(val) ) return +val
        else if ( this.is_json(val) ) return JSON.parse(val)
        else if ( val.toLowerCase() === 'null' ) return null
        else if ( val.toLowerCase() === 'undefined' ) return undefined
        else return val
    },

    /**
     * Checks if a string is valid JSON.
     * @param string
     * @deprecated Prefer using {@link module:libflitter/utility/UtilityUnit~UtilityUnit}
     * @return {boolean} - true if the string is valid JSON
     */
    is_json(string){
        try {
            JSON.parse(string)
            return true
        } 
        catch (e) {
            return false
        }
    }
}
